/**
 * directorySlider v0.9 - Loads all images in a specified directory and creates a slide show
 * Author: Justin W. Hall
 * http://www.justinwhall.com/directory-jquery-slider/
 *
 * License: GPL v3
 */

(function($){
   var directorySlider = function(element, options)
   {
		var elem = $(element),
	      obj = this,
	      elemId = elem[0].id
	      isPaused = false;  // toggle for timer
	      index = 1;	// initialize slide counter

		// Merge config settings
		var config = $.extend({
		    animation: 'slide',
		    filebase: 'slide_',
		    extension: 'jpg',
		    speed: 1000,
		    timeout: 4000,
		    directory: null,
		    numslides: null,
		    height: null,
		    width: null
		}, options || {});

      // Get slides
      var slides = [],
      slideNumber = 1;

		while(slideNumber <= config.numslides){
	      slides.push('<img src="' + config.directory + config.filebase + slideNumber + '.' + config.extension + '" />');
	      slideNumber++;
	    }

       // append slideshow
       // apply slide wrap 1st
       var slideWrap = $("<div class='" + elemId + "-slide-wrap'></div>");
           slideWrap.appendTo(elem);

        // append slide and position absolutley
        $.each(slides, function(index, val) {
         	$(val).css({
           	opacity: 0,
           	width: config.width // ADDED THIS SO WE DON'T NEED TO HAVE ALL IMAGES WITH SAME HEIGHT & WIDTH
         	}).appendTo(slideWrap);
       	});
       
	      var firstSlide = elem.find('img:first-child');
	      $(firstSlide).css('opacity', 1);

		/*
		**	 Set Timer
		*/
	   setInterval(function(){
	      var firstSlide = elem.find('img:first-child'),
	      	prevSlide = elem.find('img:nth-child(1)'),
				lastSlide = elem.find('img:last-child');

			if(!isPaused) {
		      // Apply animation
		      switch(config.animation){

		   	default:
					var firstSlide = elem.find('img:first-child'),
	   		nextSlide = elem.find('img:nth-child(2)'),
	     		lastSlide = elem.find('img:last-child');
	     	
	     	// get the image number from the src filename
			str = String(nextSlide[0].src);
			start = str.indexOf("slide_");
			end = str.indexOf(".jpg");
			index = str.substring(start+6, end);
	     
	   	$(firstSlide).animate({
		      opacity: 0},
		      700, function() {
		      $(firstSlide).insertAfter(lastSlide).css('opacity', 0);
		      $(nextSlide).css('opacity',1);
	   	});

	      // update slide counter
			$(".counter").html(index+" of "+options.numslides);
		      }
	      }
		}, config.timeout);

		// set up buttons html
	   var buttons = $("<div class='buttons'>"
			+ "<p class='counter'>"+index+" of "+options.numslides+"</p><br>"
			+ "<button type='button' id='prev'>Prev</button><br><br><br>"
			+ "<button type='button' id='play' style='background-color:#BCFFAA'>Pause</button><br><br><br>"
			+ "<button type='button' id='next'>Next</button>"
			+ "</div>");
	   $(".directorySlider").before(buttons);

	   // next button function    
	   $("#next").click(function(){
	   	isPaused = true;
	 		$("#play").html("Resume");
	 		$("#play").css({"backgroundColor": "#FFBEDD", "color": "black"});
	   	var firstSlide = elem.find('img:first-child'),
	   		nextSlide = elem.find('img:nth-child(2)'),
	     		lastSlide = elem.find('img:last-child');
	     	
	     	// get the image number from the src filename
			str = String(nextSlide[0].src);
			start = str.indexOf("slide_");
			end = str.indexOf(".jpg");
			index = str.substring(start+6, end);
	     
	   	$(firstSlide).animate({
		      opacity: 0}, 700, 
		      function() {
		      	(firstSlide).insertAfter(lastSlide).css('opacity', 0);
		      	$(nextSlide).css('opacity',1);
	   		}
	   	);

	      // update slide counter
			$(".counter").html(index+" of "+options.numslides);
		});

		// Previous button function
		
		$("#prev").click(function(){
			isPaused = true;
			$("#play").html("Resume");
			$("#play").css({"backgroundColor": "#FFBEDD", "color": "black"});
			
			var firstSlide = elem.find('img:first-child'),
	   		nextSlide = elem.find('img:nth-child(2)'),
	     		lastSlide = elem.find('img:last-child');
			
			// get the image number from the src filename
			str = String(lastSlide[0].src);
			start = str.indexOf("slide_");
			end = str.indexOf(".jpg");
			index = str.substring(start+6, end);
		  
			$(firstSlide).animate({
				opacity: 0}, 700,
			   function() {
					$(lastSlide).insertBefore(firstSlide).css('opacity', 0);
					$(lastSlide).css('opacity', 1);
				});

	      // update counter
			$(".counter").html(index+" of "+options.numslides);
			});
	      
		// Play - Pause button function
		$( "#play" ).click(function() {
			if (!isPaused) {
				isPaused = true;
				$("#play").html("Play");
				$("#play").css({"backgroundColor": "#FFBEDD", "color": "black"});
			}
			else {
				isPaused = false;
				$("#play").html("Pause");
				$("#play").css({"backgroundColor": "#BCFFAA", "color": "black"});
			}
		});
	};
   

	// Call to set up directorySlider 
   $.fn.directorySlider = function(options)
   {
       return this.each(function()
       {
           var element = $(this);

           // Return early if this element already has a plugin instance
           if (element.data('directoryslider')) return;

           // pass options to plugin constructor
           var directoryslider = new directorySlider(this, options);

           // Store plugin object in this element's data
           element.data('directoryslider', directoryslider);
       });
   };
})(jQuery);
